@@ -143,6 +143,13 @@ class REST(object):
         method = 'POST'
         return self.request(path, method, call_params)
 
+    def reload_cache_config(self, call_params):
+        """REST Reload Plivo Cache Config helper
+        """
+        path = '/' + self.api_version + '/ReloadCacheConfig/'
+        method = 'POST'
+        return self.request(path, method, call_params)
+
     def call(self, call_params):
         """REST Call Helper
         """
@@ -649,13 +656,15 @@ class Conference(Element):
     callbackMethod: submit to 'callbackUrl' url using GET or POST
     digitsMatch: a list of matching digits to send with callbackUrl
             Can be a list of digits patterns separated by comma.
-
+    floorEvent: 'true' or 'false'. When this member holds the floor,
+                send notification to callbackUrl. (default 'false')
     """
     VALID_ATTRS = ('muted','beep','startConferenceOnEnter',
                    'endConferenceOnExit','waitSound','enterSound', 'exitSound',
                    'timeLimit', 'hangupOnStar', 'maxMembers', 'recordFilePath',
                    'recordFileFormat', 'recordFileName', 'action', 'method',
-                   'digitsMatch', 'callbackUrl', 'callbackMethod', 'stayAlone')
+                   'digitsMatch', 'callbackUrl', 'callbackMethod', 
+                   'stayAlone', 'floorEvent')
 
     def __init__(self, room, **kwargs):
         Element.__init__(self, **kwargs)
